@@ -10,6 +10,7 @@ use github_actions_models::common::{RepositoryUses, Uses};
 
 use super::{Audit, AuditLoadError, audit_meta};
 use crate::{
+    config::Config,
     finding::{Confidence, Finding, Fix, Severity, location::Routable as _},
     github_api,
     models::{StepCommon, action::CompositeStep, uses::RepositoryUsesExt as _, workflow::Step},
@@ -256,7 +257,7 @@ impl KnownVulnerableActions {
 }
 
 impl Audit for KnownVulnerableActions {
-    fn new(state: &AuditState<'_>) -> Result<Self, AuditLoadError>
+    fn new(state: &AuditState) -> Result<Self, AuditLoadError>
     where
         Self: Sized,
     {
@@ -273,43 +274,42 @@ impl Audit for KnownVulnerableActions {
             .map(|client| KnownVulnerableActions { client })
     }
 
-    fn audit_step<'doc>(&self, step: &Step<'doc>) -> Result<Vec<Finding<'doc>>> {
+    fn audit_step<'doc>(&self, step: &Step<'doc>, _config: &Config) -> Result<Vec<Finding<'doc>>> {
         self.process_step(step)
     }
 
-    fn audit_composite_step<'doc>(&self, step: &CompositeStep<'doc>) -> Result<Vec<Finding<'doc>>> {
+    fn audit_composite_step<'doc>(
+        &self,
+        step: &CompositeStep<'doc>,
+        _config: &Config,
+    ) -> Result<Vec<Finding<'doc>>> {
         self.process_step(step)
     }
 }
 
 #[cfg(test)]
 mod tests {
-    use std::path::Path;
-
     use insta::assert_snapshot;
 
     use super::*;
     use crate::{
         models::{AsDocument, workflow::Workflow},
-        registry::InputKey,
+        registry::input::InputKey,
     };
 
     // Helper function to create a test KnownVulnerableActions instance
     fn create_test_audit() -> KnownVulnerableActions {
-        let config = crate::config::Config::default();
-        let state = crate::state::AuditState {
-            config: &config,
-            no_online_audits: false,
-            gh_client: Some(
+        let state = crate::state::AuditState::new(
+            false,
+            Some(
                 github_api::Client::new(
-                    &github_api::GitHubHost::Standard("github.com".to_string()),
-                    &github_api::GitHubToken::new("fake").unwrap(),
-                    Path::new("/tmp"),
+                    github_api::GitHubHost::default(),
+                    github_api::GitHubToken::new("fake").unwrap(),
+                    "/tmp".into(),
                 )
                 .unwrap(),
             ),
-            gh_hostname: crate::github_api::GitHubHost::Standard("github.com".to_string()),
-        };
+        );
         KnownVulnerableActions::new(&state).unwrap()
     }
 
@@ -328,7 +328,7 @@ jobs:
         run: echo "hello"
 "#;
 
-        let key = InputKey::local("test_checkout.yml", None::<&str>).unwrap();
+        let key = InputKey::local("fakegroup".into(), "test_checkout.yml", None::<&str>).unwrap();
         let workflow = Workflow::from_string(workflow_content.to_string(), key).unwrap();
         let job = workflow.jobs().next().unwrap();
         let steps: Vec<_> = match job {
@@ -380,7 +380,7 @@ jobs:
         run: npm install
 "#;
 
-        let key = InputKey::local("test_setup_node.yml", None::<&str>).unwrap();
+        let key = InputKey::local("fakegroup".into(), "test_setup_node.yml", None::<&str>).unwrap();
         let workflow = Workflow::from_string(workflow_content.to_string(), key).unwrap();
         let job = workflow.jobs().next().unwrap();
         let steps: Vec<_> = match job {
@@ -434,7 +434,8 @@ jobs:
         run: echo "test"
 "#;
 
-        let key = InputKey::local("test_third_party.yml", None::<&str>).unwrap();
+        let key =
+            InputKey::local("fakegroup".into(), "test_third_party.yml", None::<&str>).unwrap();
         let workflow = Workflow::from_string(workflow_content.to_string(), key).unwrap();
         let job = workflow.jobs().next().unwrap();
         let steps: Vec<_> = match job {
@@ -495,7 +496,7 @@ jobs:
         run: npm install
 "#;
 
-        let key = InputKey::local("test_multiple.yml", None::<&str>).unwrap();
+        let key = InputKey::local("fakegroup".into(), "test_multiple.yml", None::<&str>).unwrap();
         let workflow = Workflow::from_string(workflow_content.to_string(), key).unwrap();
         let job = workflow.jobs().next().unwrap();
         let steps: Vec<_> = match job {
@@ -581,7 +582,7 @@ jobs:
           param: value
 "#;
 
-        let key = InputKey::local("test_subpath.yml", None::<&str>).unwrap();
+        let key = InputKey::local("fakegroup".into(), "test_subpath.yml", None::<&str>).unwrap();
         let workflow = Workflow::from_string(workflow_content.to_string(), key).unwrap();
         let job = workflow.jobs().next().unwrap();
         let steps: Vec<_> = match job {
@@ -630,7 +631,8 @@ jobs:
         uses: actions/checkout@v2
 "#;
 
-        let key = InputKey::local("test_first_patched.yml", None::<&str>).unwrap();
+        let key =
+            InputKey::local("fakegroup".into(), "test_first_patched.yml", None::<&str>).unwrap();
         let workflow = Workflow::from_string(workflow_content.to_string(), key).unwrap();
         let job = workflow.jobs().next().unwrap();
         let steps: Vec<_> = match job {
@@ -680,7 +682,7 @@ jobs:
         uses: actions/checkout@v2 # this comment stays
 "#;
 
-        let key = InputKey::local("test_non_commit.yml", None::<&str>).unwrap();
+        let key = InputKey::local("fakegroup".into(), "test_non_commit.yml", None::<&str>).unwrap();
         let workflow = Workflow::from_string(workflow_content.to_string(), key).unwrap();
         let job = workflow.jobs().next().unwrap();
         let steps: Vec<_> = match job {
@@ -716,13 +718,7 @@ jobs:
     #[test]
     fn test_offline_audit_state_creation() {
         // Test that we can create an audit state without a GitHub token
-        let config = crate::config::Config::default();
-        let state = crate::state::AuditState {
-            config: &config,
-            no_online_audits: true,
-            gh_client: None,
-            gh_hostname: crate::github_api::GitHubHost::Standard("github.com".to_string()),
-        };
+        let state = crate::state::AuditState::default();
 
         // This should fail because no GitHub token is provided
         let audit_result = KnownVulnerableActions::new(&state);
@@ -745,28 +741,27 @@ jobs:
         uses: actions/download-artifact@7a1cd3216ca9260cd8022db641d960b1db4d1be4  # v4.0.0
 "#;
 
-        let key = InputKey::local("dummy.yml", None::<&str>).unwrap();
+        let key = InputKey::local("fakegroup".into(), "dummy.yml", None::<&str>).unwrap();
         let workflow = Workflow::from_string(workflow_content.to_string(), key).unwrap();
 
-        let config = crate::config::Config::default();
-        let state = crate::state::AuditState {
-            config: &config,
-            no_online_audits: false,
-            gh_client: Some(
+        let state = crate::state::AuditState::new(
+            false,
+            Some(
                 github_api::Client::new(
-                    &github_api::GitHubHost::Standard("github.com".to_string()),
-                    &github_api::GitHubToken::new(&std::env::var("GH_TOKEN").unwrap()).unwrap(),
-                    Path::new("/tmp"),
+                    github_api::GitHubHost::default(),
+                    github_api::GitHubToken::new(&std::env::var("GH_TOKEN").unwrap()).unwrap(),
+                    "/tmp".into(),
                 )
                 .unwrap(),
             ),
-            gh_hostname: crate::github_api::GitHubHost::Standard("github.com".to_string()),
-        };
+        );
 
         let audit = KnownVulnerableActions::new(&state).unwrap();
 
         let input = workflow.into();
-        let findings = audit.audit(&input).unwrap();
+        let findings = audit
+            .audit(KnownVulnerableActions::ident(), &input, &Config::default())
+            .unwrap();
         assert_eq!(findings.len(), 1);
 
         let new_doc = findings[0].fixes[0].apply(input.as_document()).unwrap();
@@ -801,28 +796,27 @@ jobs:
       - name: Commit pinned action
         uses: actions/download-artifact@7a1cd3216ca9260cd8022db641d960b1db4d1be4
 "#;
-        let key = InputKey::local("dummy.yml", None::<&str>).unwrap();
+        let key = InputKey::local("fakegroup".into(), "dummy.yml", None::<&str>).unwrap();
         let workflow = Workflow::from_string(workflow_content.to_string(), key).unwrap();
 
-        let config = crate::config::Config::default();
-        let state = crate::state::AuditState {
-            config: &config,
-            no_online_audits: false,
-            gh_client: Some(
+        let state = crate::state::AuditState::new(
+            false,
+            Some(
                 github_api::Client::new(
-                    &github_api::GitHubHost::Standard("github.com".to_string()),
-                    &github_api::GitHubToken::new(&std::env::var("GH_TOKEN").unwrap()).unwrap(),
-                    Path::new("/tmp"),
+                    github_api::GitHubHost::default(),
+                    github_api::GitHubToken::new(&std::env::var("GH_TOKEN").unwrap()).unwrap(),
+                    "/tmp".into(),
                 )
                 .unwrap(),
             ),
-            gh_hostname: crate::github_api::GitHubHost::Standard("github.com".to_string()),
-        };
+        );
 
         let audit = KnownVulnerableActions::new(&state).unwrap();
 
         let input = workflow.into();
-        let findings = audit.audit(&input).unwrap();
+        let findings = audit
+            .audit(KnownVulnerableActions::ident(), &input, &Config::default())
+            .unwrap();
         assert_eq!(findings.len(), 1);
 
         let new_doc = findings[0].fixes[0].apply(input.as_document()).unwrap();
